@@ -6,10 +6,10 @@ Created on 24.08.2010
 '''
 from django.conf import urls
 
-from m3.ui.actions import ActionController
+from m3 import authenticated_user_required
+from m3.actions import ActionController
 from m3_logview import actions
 
-from m3.helpers.users import authenticated_user_required
 
 m3_logview_controller = ActionController('/m3/logview')
 
